# EsisteOdonimoGetQueryParamResponse

Successful operation


## Fields

| Field              | Type               | Required           | Description        | Example            |
| ------------------ | ------------------ | ------------------ | ------------------ | ------------------ |
| `res`              | *Optional[str]*    | :heavy_minus_sign: | N/A                | esisteodonimo      |
| `data`             | *Optional[bool]*   | :heavy_minus_sign: | N/A                |                    |